@@ -8,7 +8,7 @@ from pathlib import Path
 
 from .config import Config
 from .lunar_client import LunarError
-from .data import DataClient, DatasetClient
+from .data import DataClient, DatasetClient, QueryClient
 from .ml import ModelRegistry
 from .rec import ChannelClient, ExperimentClient, RecommendationClient
 
@@ -21,6 +21,7 @@ SERVICE_CLIENT_MAP = {
     "recommend": {"client": RecommendationClient, "api_type": "REC"},
     "data": {"client": DataClient, "api_type": "DATA"},
     "dataset": {"client": DatasetClient, "api_type": "DATA"},
+    "query": {"client": QueryClient, "api_type": "DATA"},
 }
 
 
